Module creation

Module creation 

Creation command handlers (create, open)

Structs

CreateArgs
Arguments for the create subcommand
OpenArgs
Arguments for the open subcommand

Enums

TierArg
Tier argument for CLI

Functions

apply_capacity_override
apply_ticket_with_warning
Apply a ticket with a warning if capacity is reduced. Uses the deprecated apply_ticket method for local/dev use cases where cryptographic verification is not required.
bind_to_dashboard_memory
Bind a memory file to a dashboard memory, syncing capacity ticket
handle_create
Handler for memvid create
handle_open
Handler for memvid open