pub struct PutManyRequest {
pub title: String,
pub label: String,
pub text: String,
pub uri: Option<String>,
pub tags: Vec<String>,
pub labels: Vec<String>,
pub metadata: Value,
pub embedding: Option<Vec<f32>>,
pub chunk_embeddings: Option<Vec<Vec<f32>>>,
}Expand description
JSON input format for put-many requests
Fields
title: Stringlabel: Stringtext: Stringuri: Option<String>labels: Vec<String>metadata: Valueembedding: Option<Vec<f32>>Pre-computed embedding vector for the parent document (e.g., from OpenAI)
chunk_embeddings: Option<Vec<Vec<f32>>>Pre-computed embeddings for each chunk (matched by index) If the document gets chunked, these embeddings are assigned to each chunk frame. The number of chunk embeddings should match the number of chunks that will be created.