Model management commands for all model types: embeddings, rerankers, and LLMs.
Supports listing, installing, and removing models for semantic search, reranking, and local LLM inference.
Structs
- Installed
Model - Information about an installed model
- Models
Args - Model management commands
- Models
Install Args - Models
List Args - Models
Remove Args - Models
Verify Args
Enums
- Clip
Model - CLIP models available for installation
- Embedding
Model - Local embedding models available for installation
- LlmModel
- Known LLM models available for installation
- Model
Type - Models
Command - NerModel
- NER models available for installation
- Reranker
Model - Local reranker models available for installation
Functions
- default_
enrichment_ model - Get the default LLM model for enrichment
- get_
installed_ model_ path - Get the path to an installed model, or None if not installed
- handle_
models - Handle the models command
- handle_
models_ install - Handle model installation
- handle_
models_ list - Handle listing models
- handle_
models_ remove - Handle model removal
- handle_
models_ verify - Handle model verification