pub struct CandlePhiEngine { /* private fields */ }Expand description
Candle-based Phi-3 enrichment engine using quantized GGUF.
Implementations
Sourceimpl CandlePhiEngine
impl CandlePhiEngine
Sourcepub fn from_hub(repo: Option<&str>) -> Self
pub fn from_hub(repo: Option<&str>) -> Self
Create a new Candle Phi engine that loads from Hugging Face Hub.
Sourcepub fn from_local(path: PathBuf) -> Self
pub fn from_local(path: PathBuf) -> Self
Create a new Candle Phi engine that loads from a local GGUF file.
Sourcepub fn from_memvid_models(models_dir: PathBuf) -> Self
pub fn from_memvid_models(models_dir: PathBuf) -> Self
Create a new Candle Phi engine that uses the memvid models directory. Downloads the model to ~/.memvid/models/llm/phi-3-mini-q4/ if not present.