Module error

Module error 

CLI-specific error types and rendering helpers.

Structs

ApiKeyRequiredMessage
Error indicating that an API key is required for large files
CapacityExceededMessage
Error indicating that the memory has reached its capacity limit
DuplicateUriError
Error indicating that a frame with the same URI already exists
MemoryAlreadyBoundMessage
Error indicating that a memory is already bound to a different dashboard memory

Functions

render_error
Render a fallible CLI error into a stable exit code + human message.