Skip to main contentModule commands
Source pub use binding::handle_binding;pub use binding::BindingArgs;pub use capsule::handle_lock;pub use capsule::handle_unlock;pub use capsule::LockArgs;pub use capsule::UnlockArgs;pub use config::handle_config;pub use config::ConfigArgs;pub use config::ConfigCheckArgs;pub use config::ConfigCommand;pub use config::ConfigGetArgs;pub use config::ConfigListArgs;pub use config::ConfigSetArgs;pub use config::ConfigUnsetArgs;pub use config::PersistentConfig;pub use data::handle_api_fetch;pub use data::handle_correct;pub use data::handle_delete;pub use data::handle_put;pub use data::handle_update;pub use data::ApiFetchArgs;pub use data::CorrectArgs;pub use data::DeleteArgs;pub use data::LockCliArgs;pub use data::PutArgs;pub use data::UpdateArgs;pub use data::handle_put_many;pub use data::PutManyArgs;pub use enrich::handle_enrich;pub use enrich::handle_export;pub use enrich::handle_facts;pub use enrich::handle_memories;pub use enrich::handle_schema;pub use enrich::handle_state;pub use enrich::EnrichArgs;pub use enrich::EnrichEngine;pub use enrich::ExportArgs;pub use enrich::ExportFormat;pub use enrich::FactsArgs;pub use enrich::MemoriesArgs;pub use enrich::SchemaArgs;pub use enrich::SchemaCommand;pub use enrich::SchemaInferArgs;pub use enrich::SchemaListArgs;pub use enrich::StateArgs;pub use follow::handle_follow;pub use follow::FollowArgs;pub use follow::FollowCommand;pub use follow::FollowEntitiesArgs;pub use follow::FollowStatsArgs;pub use follow::FollowTraverseArgs;pub use inspection::extension_from_mime;pub use inspection::frame_to_json;pub use inspection::handle_stats;pub use inspection::handle_view;pub use inspection::handle_who;pub use inspection::parse_preview_bounds;pub use inspection::print_frame_summary;pub use inspection::PreviewBounds;pub use inspection::StatsArgs;pub use inspection::ViewArgs;pub use inspection::WhoArgs;pub use maintenance::handle_doctor;pub use maintenance::handle_nudge;pub use maintenance::handle_process_queue;pub use maintenance::handle_verify;pub use maintenance::handle_verify_single_file;pub use maintenance::DoctorArgs;pub use maintenance::NudgeArgs;pub use maintenance::ProcessQueueArgs;pub use maintenance::VerifyArgs;pub use maintenance::VerifySingleFileArgs;pub use models::default_enrichment_model;pub use models::get_installed_model_path;pub use models::handle_models;pub use models::LlmModel;pub use models::ModelsArgs;pub use models::ModelsCommand;pub use models::ModelsInstallArgs;pub use models::ModelsListArgs;pub use models::ModelsRemoveArgs;pub use models::ModelsVerifyArgs;pub use plan::handle_plan;pub use plan::PlanArgs;pub use plan::PlanClearArgs;pub use plan::PlanCommand;pub use plan::PlanShowArgs;pub use plan::PlanSyncArgs;pub use search::handle_ask;pub use search::handle_audit;pub use search::handle_find;pub use search::handle_timeline;pub use search::handle_vec_search;pub use search::AskArgs;pub use search::AskModeArg;pub use search::AuditArgs;pub use search::AuditFormat;pub use search::FindArgs;pub use search::SearchMode;pub use search::TimelineArgs;pub use search::VecSearchArgs;pub use search::handle_when;pub use search::WhenArgs;pub use session::handle_session;pub use session::SessionArgs;pub use sketch::handle_sketch;pub use sketch::SketchArgs;pub use sketch::SketchBuildArgs;pub use sketch::SketchCommand;pub use sketch::SketchInfoArgs;pub use sketch::SketchVariantArg;pub use status::handle_status;pub use status::StatusArgs;pub use tables::handle_tables;pub use tables::ExportFormatArg;pub use tables::QualityArg;pub use tables::TablesArgs;pub use tables::TablesCommand;pub use tables::TablesExportArgs;pub use tables::TablesImportArgs;pub use tables::TablesListArgs;pub use tables::TablesViewArgs;pub use tickets::handle_ticket_apply;pub use tickets::handle_ticket_issue;pub use tickets::handle_ticket_revoke;pub use tickets::handle_ticket_status;pub use tickets::handle_ticket_sync;pub use tickets::handle_tickets;pub use tickets::TicketsApplyArgs;pub use tickets::TicketsArgs;pub use tickets::TicketsCommand;pub use tickets::TicketsIssueArgs;pub use tickets::TicketsRevokeArgs;pub use tickets::TicketsStatusArgs;pub use tickets::TicketsSyncArgs;pub use creation::*;pub use debug::*;pub use version::*;
- binding
- Commands for managing memory bindings to dashboard
- capsule
- config
- Config management commands (set, get, list, unset, check)
- creation
- Creation command handlers (create, open)
- data
- Data operation command handlers (put, update, delete, api-fetch).
- debug
- Debug command handler
- enrich
- Enrichment command handler for extracting memory cards from frames.
- follow
- Logic-Mesh follow command for graph traversal.
- inspection
- Inspection command handlers (view, stats, who)
- maintenance
- Maintenance command handlers (verify, doctor, verify-single-file, nudge, process-queue).
These commands surface integrity checks, healing workflows, and lock inspection
for
.mv2 files without mutating unrelated state. - models
- Model management commands for all model types: embeddings, rerankers, and LLMs.
- plan
- Plan management commands (show, sync)
- search
- Search & retrieval command handlers (find, vec-search, ask, timeline, when).
- session
- CLI commands for time-travel replay session management.
- sketch
- Sketch track commands for fast candidate generation.
- status
- Status command - Show configuration and system status
- tables
- Table extraction and management commands.
- tickets
- Ticket management command handlers (list, issue, revoke, sync, apply)
- version
- Version command handler