Module commands

Module commands 

Re-exports

pub use binding::handle_binding;
pub use binding::handle_unbind;
pub use binding::BindingArgs;
pub use binding::UnbindArgs;
pub use capsule::handle_lock;
pub use capsule::handle_unlock;
pub use capsule::LockArgs;
pub use capsule::UnlockArgs;
pub use enrich::handle_enrich;
pub use enrich::handle_memories;
pub use enrich::EnrichArgs;
pub use enrich::EnrichEngine;
pub use enrich::MemoriesArgs;
pub use follow::handle_follow;
pub use follow::FollowArgs;
pub use follow::FollowCommand;
pub use follow::FollowEntitiesArgs;
pub use follow::FollowStatsArgs;
pub use follow::FollowTraverseArgs;
pub use inspection::extension_from_mime;
pub use inspection::frame_to_json;
pub use inspection::handle_stats;
pub use inspection::handle_view;
pub use inspection::handle_who;
pub use inspection::parse_preview_bounds;
pub use inspection::print_frame_summary;
pub use inspection::PreviewBounds;
pub use inspection::StatsArgs;
pub use inspection::ViewArgs;
pub use inspection::WhoArgs;
pub use maintenance::handle_doctor;
pub use maintenance::handle_nudge;
pub use maintenance::handle_verify;
pub use maintenance::handle_verify_single_file;
pub use maintenance::DoctorArgs;
pub use maintenance::NudgeArgs;
pub use maintenance::VerifyArgs;
pub use maintenance::VerifySingleFileArgs;
pub use models::default_enrichment_model;
pub use models::get_installed_model_path;
pub use models::handle_models;
pub use models::LlmModel;
pub use models::ModelsArgs;
pub use models::ModelsCommand;
pub use models::ModelsInstallArgs;
pub use models::ModelsListArgs;
pub use models::ModelsRemoveArgs;
pub use models::ModelsVerifyArgs;
pub use search::handle_ask;
pub use search::handle_audit;
pub use search::handle_find;
pub use search::handle_timeline;
pub use search::AskArgs;
pub use search::AskModeArg;
pub use search::AuditArgs;
pub use search::AuditFormat;
pub use search::FindArgs;
pub use search::SearchMode;
pub use search::TimelineArgs;
pub use search::VecSearchArgs;
pub use search::handle_when;
pub use search::WhenArgs;
pub use tables::handle_tables;
pub use tables::ExportFormatArg;
pub use tables::ExtractionModeArg;
pub use tables::QualityArg;
pub use tables::TablesArgs;
pub use tables::TablesCommand;
pub use tables::TablesExportArgs;
pub use tables::TablesImportArgs;
pub use tables::TablesListArgs;
pub use tables::TablesViewArgs;
pub use tickets::handle_ticket_apply;
pub use tickets::handle_ticket_issue;
pub use tickets::handle_ticket_revoke;
pub use tickets::handle_ticket_status;
pub use tickets::handle_ticket_sync;
pub use tickets::handle_tickets;
pub use tickets::TicketsApplyArgs;
pub use tickets::TicketsArgs;
pub use tickets::TicketsCommand;
pub use tickets::TicketsIssueArgs;
pub use tickets::TicketsRevokeArgs;
pub use tickets::TicketsStatusArgs;
pub use tickets::TicketsSyncArgs;
pub use session::handle_session;
pub use session::SessionArgs;
pub use creation::*;
pub use data::*;
pub use debug::*;
pub use version::*;

Modules

binding
Commands for managing memory bindings to dashboard
capsule
creation
Creation command handlers (create, open)
data
Data operation command handlers (put, update, delete, api-fetch).
debug
Debug command handler
enrich
Enrichment command handler for extracting memory cards from frames.
follow
Logic-Mesh follow command for graph traversal.
inspection
Inspection command handlers (view, stats, who)
maintenance
Maintenance command handlers (verify, doctor, verify-single-file, nudge). These commands surface integrity checks, healing workflows, and lock inspection for .mv2 files without mutating unrelated state.
models
Model management commands for all model types: embeddings, rerankers, and LLMs.
search
Search & retrieval command handlers (find, vec-search, ask, timeline, when).
session
CLI commands for time-travel replay session management.
session_web
Web server for the Time Machine session replay UI.
tables
Table extraction and management commands.
tickets
Ticket management command handlers (list, issue, revoke, sync, apply)
version
Version command handler