CLI-specific error types and rendering helpers.
Structs
- ApiKey
Required Message - Error indicating that an API key is required for large files
- Capacity
Exceeded Message - Error indicating that the memory has reached its capacity limit
- Duplicate
UriError - Error indicating that a frame with the same URI already exists
- Memory
Already Bound Message - Error indicating that a memory is already bound to a different dashboard memory
Functions
- render_
error - Render a fallible CLI error into a stable exit code + human message.